﻿<# 
    UserLastLogon
    Script per la verifica dell'ultimo logon di un determinato utente in Active Directory
    Autore: Roberto Bonfa'
	Versione 2.0
#>

# Importo il modulo di Active Directory
Import-Module ActiveDirectory

# Funzione per ottenere l'ultimo logon di un utente
function Get-ADUserLastLogon([string]$userName) {
    try {
        $dcs = Get-ADDomainController -Filter { Name -like "*" }
        $time = 0

        foreach ($dc in $dcs) {
            $hostname = $dc.HostName
            $user = Get-ADUser $userName -Properties lastLogon -Server $hostname

            if ($user.LastLogon -gt $time) {
                $time = $user.LastLogon
            }
        }

        if ($time -eq 0) {
            Write-Host "Nessun logon trovato per l'utente $userName"
        } else {
            $dt = [DateTime]::FromFileTime($time)
            Write-Host "$userName si è loggato l'ultimo volta il: $dt"
        }
    } catch {
        Write-Host "Errore: $_"
    }
}

# Chiedo l'input dell'utente
$User = Read-Host -Prompt 'Inserisci il nome utente'
Get-ADUserLastLogon -UserName $User

# Pausa finale
Write-Host "Premi un tasto per terminare"
$host.UI.RawUI.ReadKey("NoEcho,IncludeKeyDown")
